@@ -34,7 +34,7 @@ def validate_principal(principal: str) -> None:
     if re.match(r"^arn:aws:iam::\d{12}:root$", principal):
         return
 
-    principal_pattern = r"(?=.{1,64}$)([\w\+=,\.@-]+\/)*[\w\+=,\.@-]+$"
+    principal_pattern = r"(?:(?=.{1,64}\/)[\w\+=,\.@-]+\/)*(?=.{1,64}$)[\w\+=,\.@-]+$"
 
     # An AWS IAM user ARN, for example, "arn:aws:iam::123456789012:user/user-name"
     if re.match(
@@ -54,17 +54,7 @@ def validate_principal(principal: str) -> None:
     # An AWS IAM assumed-role session, for example,
     # "arn:aws:iam::123456789012:assumed-role/role-name/role-session-name"
     if re.match(
-        (
-            r"^arn:aws:sts::\d{12}:assumed-role\/(?=.{1,64}\/[^\/]+$)([\w\+=,\.@-]+\/)*"
-            r"[\w\+=,\.@-]+\/(?=.{1,64}$)[\w\+=,\.@-]+$"
-        ),
-        principal,
-    ):
-        return
-
-    # Custom principals patterns
-    if re.match(
-        (r"^arn:aws:iam::\d{12}:user\/system\/ap-s3-bucket-user\/[\w\+=,\.@-]{1,64}$"),
+        r"^arn:aws:sts::\d{12}:assumed-role\/" + principal_pattern,
         principal,
     ):
         return
@@ -244,3 +234,17 @@ class Tagger:
         tags["is-production"] = str(tags["environment-name"] in ["alpha", "prod"])
         tags["Name"] = name
         return tags
+
+
+class BucketDetails:
+    def __init__(self, bucket_name: str):
+        """Lets you use an existing bucket as the destination bucket, for example in
+        a MoveObjectFunction. Insert the bucket's name and get a Bucket-like object
+        that has name and Arn attributes.
+        """
+        self.name = bucket_name
+
+    @property
+    def arn(self) -> str:
+        """Return s3 Arn based on the bucket's name."""
+        return f"arn:aws:s3:::{self.name}"
